@@ -14,7 +14,8 @@ from django.utils.encoding import force_str, smart_str
 from django.utils.timezone import get_default_timezone
 from io import BytesIO
 
-from . import compat
+from adminactions import utils
+
 from .utils import (clone_instance, get_field_by_path,
                     get_field_value, get_ignored_fields,)
 
@@ -56,8 +57,7 @@ def merge(master, other, fields=None, commit=False, m2m=None, related=None):  #
 
     if related == ALL_FIELDS:
         related = [rel.get_accessor_name()
-                   for rel in compat.get_all_related_objects(master)]
-    # for rel in master._meta.get_all_related_objects(False, False, False)]
+                   for rel in utils.get_all_related_objects(master)]
 
     if m2m == ALL_FIELDS:
         m2m = set()
@@ -263,13 +263,11 @@ def export_as_xls2(queryset, fields=None, header=None,  # noqa
         if hasattr(queryset, 'model'):
             for i, fieldname in enumerate(fields):
                 try:
-                    f, __, __, __, = compat.get_field_by_name(queryset.model, fieldname)
+                    f, __, __, __, = utils.get_field_by_name(queryset.model, fieldname)
                     fmt = xls_options_default.get(f.name, xls_options_default.get(f.__class__.__name__, 'general'))
                     formats[i] = fmt
                 except FieldDoesNotExist:
                     pass
-                    # styles[i] = xlwt.easyxf(num_format_str=xls_options_default.get(col_class, 'general'))
-                    # styles[i] = xls_options_default.get(col_class, 'general')
 
         return formats
 
@@ -392,20 +390,11 @@ def export_as_xls3(queryset, fields=None, header=None,  # noqa
                     formats[fieldname] = fmt
                 except FieldDoesNotExist:
                     pass
-                    # styles[i] = xlwt.easyxf(num_format_str=xls_options_default.get(col_class, 'general'))
-                    # styles[i] = xls_options_default.get(col_class, 'general')
-
         return formats
 
     http_response = out is None
     if out is None:
-        # if filename is None:
-        # filename = filename or "%s.xls" % queryset.model._meta.verbose_name_plural.lower().replace(" ", "_")
-        # response = HttpResponse(content_type='application/vnd.ms-excel')
-        # response['Content-Disposition'] = 'attachment;filename="%s"' % filename.encode('us-ascii', 'replace')
         out = BytesIO()
-        #
-        # out = StringIO()
 
     config = xlsxwriter_options.copy()
     if options:
