@@ -85,21 +85,19 @@ class OperationManager:
 
 
 OPERATIONS = OperationManager({
-    df.CharField: [('upper', (str.upper, False, True, "convert to uppercase")),
-                   ('lower', (str.lower, False, True, "convert to lowercase")),
-                   ('capitalize', (str.capitalize, False, True, "capitalize first character")),
-                   # ('capwords', (string.capwords, False, True, "capitalize each word")),
-                   # ('swapcase', (string.swapcase, False, True, "")),
-                   ('trim', (str.strip, False, True, "leading and trailing whitespace"))],
-    df.IntegerField: [('add percent', (add_percent, True, True, "add <arg> percent to existing value")),
+    df.CharField: [('upper', (str.upper, False, True, _("convert to uppercase"))),
+                   ('lower', (str.lower, False, True, _("convert to lowercase"))),
+                   ('capitalize', (str.capitalize, False, True, _("capitalize first character"))),
+                   ('trim', (str.strip, False, True, _("leading and trailing whitespace")))],
+    df.IntegerField: [('add percent', (add_percent, True, True, _("add <arg> percent to existing value"))),
                       ('sub percent', (sub_percent, True, True, "")),
                       ('sub', (sub_percent, True, True, "")),
                       ('add', (add, True, True, ""))],
     df.BooleanField: [('swap', (negate, False, True, ""))],
     df.NullBooleanField: [('swap', (negate, False, True, ""))],
     df.EmailField: [('change domain', (change_domain, True, True, "")),
-                    ('upper', (str.upper, False, True, "convert to uppercase")),
-                    ('lower', (str.lower, False, True, "convert to lowercase"))],
+                    ('upper', (str.upper, False, True, _("convert to uppercase"))),
+                    ('lower', (str.lower, False, True, _("convert to lowercase")))],
     df.URLField: [('change protocol', (change_protocol, True, True, ""))]
 })
 
@@ -107,15 +105,10 @@ OPERATIONS = OperationManager({
 class MassUpdateForm(GenericActionForm):
     _clean = forms.BooleanField(label='clean()',
                                 required=False,
-                                help_text="if checked calls obj.clean()")
+                                help_text=_("if checked calls obj.clean()"))
 
     _validate = forms.BooleanField(label='Validate',
-                                   help_text="if checked use obj.save() instead of manager.update()")
-
-    # _unique_transaction = forms.BooleanField(label='Unique transaction',
-    # required=False,
-    # help_text="If checked create one transaction for the whole update. "
-    # "If any record cannot be updated everything will be rolled-back")
+                                   help_text=_("if checked use obj.save() instead of manager.update()"))
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -155,7 +148,6 @@ class MassUpdateForm(GenericActionForm):
                     enabler = 'chk_id_%s' % name
                     function = self.data.get('func_id_%s' % name, False)
                     if self.data.get(enabler, False):
-                        # field_object, model, direct, m2m = self._meta.model._meta.get_field_by_name(name)
                         field_object, model, direct, m2m = get_field_by_name(self._meta.model, name)
                         value = field.clean(raw_value)
                         if function:
@@ -230,7 +222,13 @@ def mass_update(modeladmin, request, queryset):  # noqa
                     old_value = getattr(record, field_name)
                     setattr(record, field_name, value_or_func(old_value))
                 else:
-                    setattr(record, field_name, value_or_func)
+                    changed_attr = getattr(record, field_name, None)
+
+                    if changed_attr.__class__.__name__ == 'ManyRelatedManager':
+                        changed_attr.set(value_or_func)
+                    else:
+                        setattr(record, field_name, value_or_func)
+
             if clean:
                 record.clean()
             record.save()
@@ -277,7 +275,7 @@ def mass_update(modeladmin, request, queryset):  # noqa
                                 [f.name for f in modeladmin.model._meta.fields])
 
     if mass_update_fields and mass_update_exclude:
-        raise Exception("Cannot set both 'mass_update_exclude' and 'mass_update_fields'")
+        raise BaseException("Cannot set both 'mass_update_exclude' and 'mass_update_fields'")
     MForm = modelform_factory(modeladmin.model, form=mass_update_form,
                               exclude=mass_update_exclude,
                               fields=mass_update_fields,
@@ -314,10 +312,10 @@ def mass_update(modeladmin, request, queryset):  # noqa
                 values = {}
                 for field_name, value in list(form.cleaned_data.items()):
                     if isinstance(form.fields[field_name], ModelMultipleChoiceField):
-                        messages.error(request, "Unable no mass update ManyToManyField without 'validate'")
+                        messages.error(request, _("Unable no mass update ManyToManyField without 'validate'"))
                         return HttpResponseRedirect(request.get_full_path())
                     elif callable(value):
-                        messages.error(request, "Unable no mass update using operators without 'validate'")
+                        messages.error(request, _("Unable no mass update using operators without 'validate'"))
                         return HttpResponseRedirect(request.get_full_path())
                     elif field_name not in ['_selected_action', '_validate', 'select_across', 'action',
                                             '_unique_transaction', '_clean']:
